@@ -13,7 +13,7 @@ from probability.distributions.mixins.attributes import AlphaFloatMixin, \
     BetaFloatMixin, NIntMixin, KIntMixin
 from probability.distributions.mixins.conjugate import ConjugateMixin
 from probability.supports import SUPPORT_BETA
-from probability.utils import is_binary, num_format
+from probability.utils import series_is_binary, num_format
 
 
 class BetaGeometricConjugate(
@@ -163,7 +163,8 @@ class BetaGeometricConjugate(
         Assumes that each experiment was completed such that the number of
         # successes observed equals the number of experiments.
 
-        https://en.wikipedia.org/wiki/Geometric_distribution#Statistical_inference
+        https://en.wikipedia.org/wiki/Geometric_distribution
+        #Statistical_inference
 
         :param data: Series of `1`s and `0`s or `True`s and `False`s
                      The data represents a series of experiments where each
@@ -219,7 +220,7 @@ class BetaGeometricConjugate(
         """
         if isinstance(prob_vars, str):
             prob_vars = [prob_vars]
-        if not all(is_binary(data[prob_var]) for prob_var in prob_vars):
+        if not all(series_is_binary(data[prob_var]) for prob_var in prob_vars):
             raise ValueError('Prob vars must be binary valued')
         if isinstance(cond_vars, str):
             cond_vars = [cond_vars]
