@@ -5,7 +5,7 @@ from scipy.stats import beta as beta_dist, rv_continuous
 from compound_types.built_ins import FloatIterable
 from probability.distributions.mixins.attributes import AlphaFloatDMixin, \
     BetaFloatDMixin
-from probability.distributions.mixins.calculable_mixins import CalculableMixin
+from probability.distributions.mixins.calculable_mixin import CalculableMixin
 from probability.distributions.mixins.rv_continuous_1d_mixin import \
     RVContinuous1dMixin
 from probability.distributions.mixins.rv_mixins import NUM_SAMPLES_COMPARISON
@@ -64,9 +64,9 @@ class Beta(
             return 0, 1
         elif alpha > 1 and beta > 1:
             return (alpha - 1) / (alpha + beta - 2)
-        elif alpha <= 1 and beta > 1:
+        elif alpha <= 1 < beta:
             return 0
-        elif alpha > 1 and beta <= 1:
+        elif alpha > 1 >= beta:
             return 1
         else:
             raise ValueError("Can't calculate mode for this distribution.")
