@@ -2,7 +2,7 @@ from scipy.stats import expon, rv_continuous
 
 from compound_types.built_ins import FloatIterable
 from probability.distributions.mixins.attributes import LambdaFloatDMixin
-from probability.distributions.mixins.calculable_mixins import CalculableMixin
+from probability.distributions.mixins.calculable_mixin import CalculableMixin
 from probability.distributions.mixins.rv_continuous_1d_mixin import \
     RVContinuous1dMixin
 from probability.utils import num_format
