@@ -3,13 +3,13 @@ from typing import Union
 from numpy import power, sum
 from scipy.stats import betabinom, rv_discrete
 
-from compound_types.built_ins import FloatIterable
+from probability.custom_types.external_custom_types import FloatArray1d
 from probability.distributions.mixins.attributes import NIntDMixin, \
     AlphaFloatDMixin, BetaFloatDMixin
-from probability.distributions.mixins.calculable_mixins import CalculableMixin
+from probability.distributions.mixins.calculable_mixin import CalculableMixin
 from probability.distributions.mixins.rv_discrete_1d_mixin import \
     RVDiscrete1dMixin
-from probability.utils import num_format
+from probability.utils import num_format, is_scalar
 
 
 class BetaBinomial(
@@ -68,17 +68,18 @@ class BetaBinomial(
         return self._n
 
     @staticmethod
-    def fit(data: FloatIterable):
+    def fit(data: FloatArray1d, **kwargs):
         raise NotImplementedError
 
     @staticmethod
-    def fits(data: FloatIterable, n: int) -> 'BetaBinomial':
+    def fits(data: FloatArray1d, n: int) -> 'BetaBinomial':
         """
         Fit a BetaBinomial distribution to the distribution of results of a
         series of N experiments, each having n trials, using the method of
         moments.
 
-        https://en.wikipedia.org/wiki/Beta-binomial_distribution#Method_of_moments
+        https://en.wikipedia.org/wiki/Beta-binomial_distribution
+        #Method_of_moments
 
         :param data: Number of successes in each trial.
         :param n: Number of trials per experiment.
@@ -105,7 +106,7 @@ class BetaBinomial(
 
     def __eq__(self, other: Union['BetaBinomial', int, float]):
 
-        if type(other) in (int, float):
+        if is_scalar(other):
             return self.pmf().at(other)
         else:
             return (
@@ -118,7 +119,7 @@ class BetaBinomial(
             self, other: Union['BetaBinomial', int, float]
     ) -> Union[bool, float]:
 
-        if type(other) in (int, float):
+        if is_scalar(other):
             return 1 - self.pmf().at(other)
         else:
             return not self.__eq__(other)
